## Installation (Ubuntu 14.04)

Install sass
```
$ sudo apt-get install ruby
$ sudo gem install sass -v 3.4.17
```

Install io.js
```
$ curl -sL https://deb.nodesource.com/setup_iojs_3.x | sudo -E bash -
$ sudo apt-get install -y iojs
```

Install dependencies
```
$ cd ./Spirit
$ npm install -y .
```

## Build

```
$ npm run gulp sass
```
